#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_ALL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_ALL_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/scalar/all.hpp>

#endif
